about summary refs log tree commit diff stats
path: root/pre.sh
diff options
context:
space:
mode:
Diffstat (limited to 'pre.sh')
-rwxr-xr-xpre.sh9
1 files changed, 8 insertions, 1 deletions
diff --git a/pre.sh b/pre.sh
index 0d614ed..28e6f2b 100755
--- a/pre.sh
+++ b/pre.sh
@@ -1,5 +1,12 @@
 #!/bin/sh
+set -e
 
-# Execute commands before building. #
+# Execute commands before building.                                            #
+# Below is an example.                                                         #
+
+sudo apt update
+sudo apt upgrade
+wget https://example.com/game_assets.zip
+unzip game_assets.zip
 
 exit 0